# Generated by Django 4.2.6 on 2024-12-04 10:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oscarbot', '0009_user_created'),
    ]

    operations = [
        migrations.CreateModel(
            name='Group',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('t_id', models.CharField(default='', max_length=100, verbose_name='Telegram ID')),
                ('username', models.CharField(blank=True, default='', max_length=200, null=True, verbose_name='Username')),
                ('name', models.CharField(blank=True, default='', max_length=200, null=True, verbose_name='Имя')),
            ],
            options={
                'verbose_name': 'группа',
                'verbose_name_plural': 'группы',
            },
        ),
        migrations.AddField(
            model_name='user',
            name='groups',
            field=models.ManyToManyField(blank=True, to='oscarbot.group'),
        ),
    ]
